@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2020-2021 CERN.
+# Copyright (C) 2020-2023 CERN.
 # Copyright (C) 2020-2021 Northwestern University.
 #
 # Flask-Resources is free software; you can redistribute it and/or modify it
@@ -9,12 +9,13 @@
 """JSON serializer."""
 
 import json
+import warnings
 
 from flask import request
-from flask.json import JSONEncoder as JSONEncoderBase
+from flask.json.provider import _default
 from speaklater import is_lazy_string
 
-from .base import MarshmallowSerializer, SerializerMixin
+from .base import BaseSerializer, MarshmallowSerializer
 
 
 def flask_request_options():
@@ -27,7 +28,7 @@ def flask_request_options():
     return {}
 
 
-class JSONEncoder(JSONEncoderBase):
+class JSONEncoder(json.JSONEncoder):
     """JSONEncoder for our custom needs.
 
     - Knows to force translate lazy translation strings.
@@ -37,10 +38,10 @@ class JSONEncoder(JSONEncoderBase):
         """Override parent's default."""
         if is_lazy_string(obj):
             return str(obj)
-        return super().default(obj)
+        return _default(obj)
 
 
-class JSONSerializer(SerializerMixin):
+class JSONSerializer(BaseSerializer):
     """JSON serializer implementation."""
 
     def __init__(self, encoder=None, options=None):
@@ -70,28 +71,3 @@ class JSONSerializer(SerializerMixin):
     def serialize_object_list(self, obj_list):
         """Dump the object list into a json string."""
         return json.dumps(obj_list, cls=self.encoder, **self.dumps_options)
-
-
-class MarshmallowJSONSerializer(MarshmallowSerializer):
-    """JSON serializing using Marshmallow to transform output.
-
-    **DEPRECATED**
-    Use MarshmallowSerializer instead
-    """
-
-    def __init__(self, schema_cls, many_schema_cls=None, **options):
-        """Initialize the serializer."""
-        super().__init__(
-            format_serializer_cls=JSONSerializer,
-            object_schema_cls=schema_cls,
-            list_schema_cls=many_schema_cls,
-            **options
-        )
-
-    def dump_one(self, obj):
-        """Dump the object with extra information."""
-        return super().dump_obj(obj)
-
-    def dump_many(self, obj_list):
-        """Dump the list of objects with extra information."""
-        return super().dump_list(obj_list)
