@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2020 CERN.
+# Copyright (C) 2022 Graz University of Technology.
 #
 # Flask-Resources is free software; you can redistribute it and/or modify
 # it under the terms of the MIT License; see LICENSE file for more details.
@@ -12,7 +13,8 @@ set -o errexit
 # Quit on unbound symbols
 set -o nounset
 
-black --check --diff flask_resources tests
-check-manifest --ignore ".*-requirements.txt"
-sphinx-build -qnNW docs docs/_build/html
-pytest
+python -m check_manifest
+python -m sphinx.cmd.build -qnNW docs docs/_build/html
+python -m pytest
+tests_exit_code=$?
+exit "$tests_exit_code"
