@@ -8,11 +8,8 @@
 
 """Resources test module."""
 
-import json
-
 import pytest
-from flask import Flask, abort
-from werkzeug.exceptions import HTTPException
+from flask import abort
 
 from flask_resources import Resource, ResourceConfig, create_error_handler, route
 from flask_resources.errors import HTTPJSONException
@@ -30,6 +27,9 @@ def resource():
 
     class HelloWorldResource(Resource):
         error_handlers = {
+            Exception: create_error_handler(
+                HTTPJSONException(code=500, description="Internal Server Error")
+            ),
             RuntimeError: create_error_handler(
                 HTTPJSONException(code=400, description="Bad request")
             ),
