@@ -12,19 +12,23 @@ from flask import Flask
 from marshmallow import Schema, fields
 from speaklater import make_lazy_string
 
-from flask_resources import (
-    BaseListSchema,
-    BaseObjectSchema,
-    MarshmallowJSONSerializer,
-    MarshmallowSerializer,
-)
-from flask_resources.serializers import JSONSerializer
+from flask_resources import BaseListSchema, BaseObjectSchema, MarshmallowSerializer
+from flask_resources.serializers import JSONSerializer, SimpleSerializer
 
 
 def _(s):
     return make_lazy_string(lambda: s)
 
 
+def dummy_xml_encoder(obj):
+    xml = "<root>"
+    for key, value in obj.items():
+        xml += f"<{key}>{value}</{key}>"
+
+    xml += "</root>"
+    return xml
+
+
 class UITestSchema(BaseObjectSchema):
     test = fields.String(dump_only=True, data_key="title_l10n")
 
@@ -40,6 +44,30 @@ def test_lazy_strings_are_serialized():
     )
 
 
+def test_xml_serializer_object():
+    serializer = SimpleSerializer(dummy_xml_encoder)
+
+    obj = {"test": "one", "also": "test"}
+    assert (
+        "<root><test>one</test><also>test</also></root>"
+        == serializer.serialize_object(obj)
+    )
+
+
+def test_xml_serializer_object_list():
+    serializer = SimpleSerializer(dummy_xml_encoder)
+
+    obj = {
+        "hits": {
+            "hits": [{"test": "one", "also": "test"}, {"test": "two", "also": "test"}]
+        }
+    }
+    assert (
+        "<root><test>one</test><also>test</also></root>\n<root><test>two</test><also>test</also></root>"
+        == serializer.serialize_object_list(obj)
+    )
+
+
 def test_prettyprint():
     app = Flask("test")
     with app.test_request_context("/?prettyprint=1"):
@@ -47,15 +75,6 @@ def test_prettyprint():
         assert '{\n  "key": "1"\n}' == serializer.serialize_object({"key": "1"})
 
 
-def test_marhsmallow_serializer():
-    class TestSchema(Schema):
-        title = fields.Str(data_key="test")
-
-    s = MarshmallowJSONSerializer(schema_cls=TestSchema)
-    assert s.serialize_object({"title": "a"}) == '{"test": "a"}'
-    assert s.serialize_object_list([{"title": "a"}]) == '[{"test": "a"}]'
-
-
 def test_marshmallow_serializer_without_context():
     serializer = MarshmallowSerializer(
         format_serializer_cls=JSONSerializer,
